SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

CREATE SCHEMA IF NOT EXISTS `haro` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci ;
USE `haro` ;

-- -----------------------------------------------------
-- Table `haro`.`kunden`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `haro`.`kunden` (
  `kdnr` VARCHAR(5) NOT NULL ,
  `name` VARCHAR(50) NULL DEFAULT NULL ,
  `strasse` VARCHAR(50) NULL DEFAULT NULL ,
  `plz` VARCHAR(5) NULL DEFAULT NULL ,
  `ort` VARCHAR(50) NULL DEFAULT NULL ,
  `passwort` VARCHAR(5) NULL DEFAULT NULL ,
  PRIMARY KEY (`kdnr`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;


-- -----------------------------------------------------
-- Table `haro`.`warengruppen`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `haro`.`warengruppen` (
  `wgnr` VARCHAR(1) NOT NULL ,
  `warengruppe` VARCHAR(50) NULL DEFAULT NULL ,
  PRIMARY KEY (`wgnr`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;


-- -----------------------------------------------------
-- Table `haro`.`teilearten`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `haro`.`teilearten` (
  `teileartnr` VARCHAR(1) NOT NULL ,
  `teileart` VARCHAR(45) NULL ,
  PRIMARY KEY (`teileartnr`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;


-- -----------------------------------------------------
-- Table `haro`.`artikel`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `haro`.`artikel` (
  `artikelnr` VARCHAR(5) NOT NULL ,
  `bezeichnung` VARCHAR(50) NULL DEFAULT NULL ,
  `wgnr` VARCHAR(1) NULL DEFAULT NULL ,
  `teileartnr` VARCHAR(1) NULL DEFAULT NULL ,
  `ekpreis` DOUBLE NULL DEFAULT NULL ,
  `vkpreis` DOUBLE NULL DEFAULT NULL ,
  `bestand` INT NULL DEFAULT NULL ,
  `meldebest` INT NULL DEFAULT NULL ,
  `aktiv` TINYINT UNSIGNED NULL DEFAULT NULL ,
  PRIMARY KEY (`artikelnr`) ,
  INDEX `FK_artikel_1` (`wgnr` ASC) ,
  INDEX `FK_artikel_2` (`teileartnr` ASC) ,
  CONSTRAINT `FK_artikel_1`
    FOREIGN KEY (`wgnr` )
    REFERENCES `haro`.`warengruppen` (`wgnr` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `FK_artikel_2`
    FOREIGN KEY (`teileartnr` )
    REFERENCES `haro`.`teilearten` (`teileartnr` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;


-- -----------------------------------------------------
-- Table `haro`.`auftragskoepfe`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `haro`.`auftragskoepfe` (
  `aufnr` VARCHAR(5) NOT NULL DEFAULT '0' ,
  `aufdat` DATE NULL DEFAULT NULL ,
  `kdnr` VARCHAR(5) NULL DEFAULT NULL ,
  `auftermin` DATE NULL DEFAULT NULL ,
  `gebucht` TINYINT NOT NULL ,
  PRIMARY KEY (`aufnr`) ,
  INDEX `FK_auftragskoepfe_1` (`kdnr` ASC) ,
  CONSTRAINT `FK_auftragskoepfe_1`
    FOREIGN KEY (`kdnr` )
    REFERENCES `haro`.`kunden` (`kdnr` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;


-- -----------------------------------------------------
-- Table `haro`.`auftragspositionen`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `haro`.`auftragspositionen` (
  `aufposnr` VARCHAR(5) NOT NULL ,
  `aufnr` VARCHAR(5) NOT NULL ,
  `artikelnr` VARCHAR(5) NULL DEFAULT NULL ,
  `aufmenge` INT NULL DEFAULT NULL ,
  PRIMARY KEY (`aufposnr`) ,
  INDEX `FK_auftragspositionen_1` (`aufnr` ASC) ,
  INDEX `FK_auftragspositionen_2` (`artikelnr` ASC) ,
  CONSTRAINT `FK_auftragspositionen_1`
    FOREIGN KEY (`aufnr` )
    REFERENCES `haro`.`auftragskoepfe` (`aufnr` ),
  CONSTRAINT `FK_auftragspositionen_2`
    FOREIGN KEY (`artikelnr` )
    REFERENCES `haro`.`artikel` (`artikelnr` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
